Method: Net::LDAP::Entry#initialize
- Defined in:
- lib/net/ldap/entry.rb
#initialize(dn = nil) ⇒ Entry
This constructor is not generally called by user code. – Originally, myhash took a block so we wouldn’t have to make sure its elements returned empty arrays when necessary. Got rid of that to enable marshalling of Entry objects, but that doesn’t work anyway, because Entry objects have singleton methods. So we define a custom dump and load.
83 84 85 86 |
# File 'lib/net/ldap/entry.rb', line 83 def initialize dn = nil # :nodoc: @myhash = {} # originally: Hash.new {|k,v| k[v] = [] } @myhash[:dn] = [dn] end |